﻿using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// Each geomety has a cut.
/// </summary>
public interface Cut{

	
	
	/// <summary>
	/// Precomputes all necessary information for a mesh, including the boundaries and the Mesh for each layer.
	/// </summary>
	/// <param name="camera">The camera indicates the viewpoint of the cut</param>
	/// <param name="targets">The targets indicates the center of the cut</param>
	void precompute (Transform camera, List<Transform> targets);

	/// <summary>
	/// Returns the transform of the gameObject that is associated with the target.
	/// </summary>
	/// <returns>Transform of the geometry object</returns>
	Transform getTransform ();
	
	/// <summary>
	/// Computes the final cut and updates the mesh of the geometry.
	/// </summary>
	/// <param name="targets">The transform of the target objects. The extend of the cut is set so that the whole target object is visible.</param>
	/// <param name="occlusionLevel">The extend of the cut depends on the current occlusionLevel. This garantees that the mesh of occluders in a previous level is still visible. The higher the occlusionLevel, the higher the extend of the cut.</param>
	/// <param name="camera">The camera indicates the current viewpoint that is used to check the visibility of the current target</param>
	void computeFinalCut (List<Transform> targets, int occlusionLevel, Camera camera);

	/// <summary>
	/// Resets the geometry objects triangles to initial value
	/// </summary>
	void resetGeometry();
}
